%bcond_with git
%if %{with git}
%define gitdate 20121223
%endif
# Use nouveau driver by default
%bcond_with nvidia


Name:		bumblebee
Summary:	Support for NVidia Optimus laptops on Linux
Group:		System/Kernel and hardware
Version:	3.0.1
Release:	4
License:	GPLv3
URL:		https://github.com/Bumblebee-Project/bumblebee
# source from git repo git://github.com/Bumblebee-Project/Bumblebee.git
# we need to change to develop branch to allow changing to nouveau without
# using nvidia paths
Source0:	https://github.com/downloads/Bumblebee-Project/Bumblebee/%{name}-%{!?with_git:%{version}}%{?with_git:%{gitdate}}.tar.%{?with_git:xz}%{!?with_git:gz}
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(libbsd)
BuildRequires:	help2man
Requires:	VirtualGL
%if %{with nvidia}
Suggests:	xorg-x11-drv-nvidia
%else
Requires:	xorg-x11-drv-nouveau
%endif
Requires:	kmod-bbswitch
Requires:	kmod-acpi_call

%description
Bumblebee daemon is a rewrite of the original Bumblebee service, providing
an elegant and stable means of managing Optimus hybrid graphics chip sets.
A primary goal of this project is to not only enable use of the discrete
GPU for rendering, but also to enable smart power management of the dGPU
when it's not in use.

%files
%doc README.markdown doc/RELEASE_NOTES_3_0_1
%{_sysconfdir}/bash_completion.d/bumblebee
%dir %{_sysconfdir}/bumblebee/
%config(noreplace) %{_sysconfdir}/bumblebee/bumblebee.conf
%config(noreplace) %{_sysconfdir}/bumblebee/xorg.conf.nouveau
%config(noreplace) %{_sysconfdir}/bumblebee/xorg.conf.nvidia
%{_sysconfdir}/init.d/bumblebeed
%{_sbindir}/bumblebeed
%{_bindir}/optirun
%{_bindir}/bumblebee-bugreport
%{_mandir}/man1/bumblebeed.1.*
%{_mandir}/man1/optirun.1.*
%{_datadir}/doc/*

%pre
/usr/sbin/groupadd bumblebee >/dev/null 2>&1 ||:
users=$(getent passwd | awk -F: '$3 >= 500 && $3 < 60000 {print $1}')
for user in $users; do
  gpasswd -a $user bumblebee >/dev/null 2>&1 ||:
done

%post
# Simple: still needs this since in release 3 services were not set
# enabled and seams that still isnt properly handeled in %%_post_service
if [ "$1" -ge "1" ]; then
  /sbin/chkconfig --add bumblebeed
  /sbin/chkconfig bumblebeed on

fi

%preun
/sbin/service bumblebeed stop >/dev/null 2>&1 ||:

%postun
/usr/sbin/groupdel bumblebee >/dev/null 2>&1 ||:

# Simple: we need to ensure bumblebee group isnt removed when upgrading
# This doesnt need exist for Mageia 2
users=$(getent passwd | awk -F: '$3 >= 500 && $3 < 60000 {print $1}')
for user in $users; do
  gpasswd -a $user bumblebee >/dev/null 2>&1 ||:
done

#--------------------------------------------------------------------
%prep
%setup -q%{?with_git:n %{name}}

%build
%{?with_git:NOCONFIGURE=1 autoreconf -fi}
%configure \
%if %{with nvidia}
CONF_DRIVER=nvidia \
CONF_DRIVER_MODULE_NVIDIA=nvidia-current \
%else
CONF_DRIVER=nouveau \
%endif
%ifarch x86_64
CONF_LDPATH_NVIDIA=%{_usr}/lib/nvidia-current:%{_libdir}/nvidia-current \
CONF_MODPATH_NVIDIA=%{_usr}/lib/nvidia-current/xorg,%{_libdir}/nvidia-current/xorg,%{_usr}/lib/xorg/modules,%{_libdir}/xorg/modules,%{_usr}/lib/xorg/extra-modules,%{_usr}/xorg/extra-modules
%else
CONF_LDPATH_NVIDIA=%{_usr}/lib/nvidia-current \
CONF_MODPATH_NVIDIA=%{_usr}/lib/nvidia-current/xorg,%{_usr}/lib/xorg/modules,%{_usr}/lib/xorg/extra-modules
%endif

make

%install
rm -rf %{buildroot}
make install DESTDIR=$RPM_BUILD_ROOT

install -d -m755 %{buildroot}/etc/init.d
install -D -m755 scripts/sysvinit/bumblebeed %{buildroot}/etc/init.d


%changelog
* Sun Dec 23 2012 Andrew Wyatt <andrew@fuduntu.org> 3.0.1-3
- Port to Fuduntu
- Use latest git checkout (still 3.0.1)

* Wed Sep 26 2012 shlomif <shlomif> 3.0.1-1.mga3
+ Revision: 298415
- New version 3.0.1

* Wed Sep 05 2012 shlomif <shlomif> 3.0-11.mga3
+ Revision: 288592
- Add a dependency on libvirtualgl.
- Spelling correction in the comment
- Fix by simple to the group deletion.

* Sun Jul 01 2012 shlomif <shlomif> 3.0-9.mga3
+ Revision: 265738
- Prevent group from getting deleted. Thanks to simplew.

* Sat Jun 30 2012 shlomif <shlomif> 3.0-8.mga3
+ Revision: 265607
- Add trailing backslashes - thanks to simplew

* Sat Jun 30 2012 shlomif <shlomif> 3.0-7.mga3
+ Revision: 265470
- Bump the release
- Made nouveau the default.
  Patch thanks to simplew.

* Wed Jun 20 2012 tmb <tmb> 3.0-6.mga3
+ Revision: 262387
- switch requires to suggests on x11-driver-video-nvidia-current as core
  must be selfcontained so a core package cant require nonfree packgage

* Sun Jun 17 2012 shlomif <shlomif> 3.0-5.mga3
+ Revision: 261203
- imported package bumblebee


* Fri Apr 13 2012 Simple <simplew8@gmailcom> 3.0-5
- Nvidia libGL is used only in optirun
- dont use CRT-0,there are machines that dont detect it
- set post script to install/upgrade to enable systemd
- fix buildrequire for X

* Fri Apr 13 2012 Simple <simplew8@gmailcom> 3.0-4
- seams that systemd macros work properly so lets use them
- add requires for scriplets
- fix source link

* Fri Apr 13 2012 Simple <simplew8@gmailcom> 3.0-3
- move to develop branch (more bug fixes)

* Mon Mar 19 2012 Simple <simplew8@gmailcom> 3.0-2
- set to build with nvidia proprietary driver by default
- clean scriptlets since systemd service is handled by default
- clean SysVinit service since systemd is used by default
- main systemd default main dir is not in /etc

* Mon Mar 19 2012 Simple <simplew8@gmailcom> 3.0-1
- 3.0 (from git), initial package
